## 1.15.1.2 (2022-11-09)

All `__nonzero__` are methods that return `bool` (#9139)

## 1.15.1.1 (2022-11-09)

Annotate known magic-method return types (#9131)

## 1.15.1 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 1.15.0 (2022-09-15)

Add type stubs for cffi (#8736)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

